#ifndef DGX_LEVEL_2D_H
#define DGX_LEVEL_2D_H

#include <engine/asset.h>
#include <engine/2d/transform.h>

#define SCT_MAX_ROWS	80
#define SCT_MAX_COLS	160

/* spacing between frames of an animation in a texture page */
#define SCT_TILE_SPACING	1
/* all tiles must be 16x16 */
#define SCT_TILE_SPRITE_SIZE	16

/*
 * tiles that are rendered on-screen applied to them for
 * player and enemy entities. Any off-screen entities will
 * will have their velocities set to 0 since collision is
 * not processed for off-screen tiles
 */
#define SCT_TILES_RENDERED_X	24
#define SCT_TILES_RENDERED_Y	18

/* screen render limits */
#define SCT_RENDER_LEFT_SIDE_LIMIT	0
#define SCT_RENDER_RIGHT_SIDE_LIMIT	(SCT_MAX_COLS - SCT_TILES_RENDERED_X)

#define SCT_RENDER_TOP_SIDE_LIMIT	0
#define SCT_RENDER_BOTTOM_SIDE_LIMIT	(SCT_MAX_ROWS - SCT_TILES_RENDERED_Y)

#define SCT_UNIQUE_TILES	225	/* number of different tiles in a 256x256px texture */
#define SCT_AIR_TILE		0	/* 0 is always the air tile */

#define SCT_LAYERS_MAX	2
#define SCT_LAYER_MAIN	0
#define SCT_LAYER_MISC	1

/*
 * a "section" is the playable area of a level. A level usually consists of multiple sections.
 * Sections can be separated via doors but can still be contained within a single level. Since
 * the Section struct takes up quite a bit of memory, only one Section struct (on_screen_section)
 * is stored in main memory. To store more than one section in memory, SectionHeaders are used.
 */
struct Section
{
	struct AssetMOL		*p_mol;
	struct Vector2u		tileset[SCT_UNIQUE_TILES];		/* uv coordinates for the actual sprites to be rendered on-screen */
	SPRT_16			layer[SCT_LAYERS_MAX][SCT_MAX_ROWS][SCT_MAX_COLS];
	DR_TPAGE		dr_tpage;				/* tpage for each SPRT */
}sct;

#endif

